TamaEx.Memory.Entity (TamaEx v0.1.18)

Summary

Functions

Parses API response data into an Entity struct.

Parses API response data into an Entity struct, raising on error.

Functions

parse(attrs)

Parses API response data into an Entity struct.

Parameters

- attrs - Map containing entity data from API response

Examples

    iex> TamaEx.Memory.Entity.parse(%{"id" => "123", "identifier" => "my-entity"})
    %TamaEx.Memory.Entity{id: "123", identifier: "my-entity"}

parse!(attrs)

Parses API response data into an Entity struct, raising on error.