TamaEx.Perception.Chain (TamaEx v0.1.18)
View SourceSummary
Functions
Parses API response data into a Chain struct.
Parses API response data into a Chain struct, raising on error.
Functions
Parses API response data into a Chain struct.
Parameters
- attrs - Map containing chain data from API response
Examples
iex> TamaEx.Perception.Chain.parse(%{"id" => "123", "name" => "My Chain"})
%TamaEx.Perception.Chain{id: "123", name: "My Chain"}
Parses API response data into a Chain struct, raising on error.