TamaEx.Neural.Space (TamaEx v0.1.18)
View SourceEmbedded schema for Neural Space entities.
Summary
Functions
Parses API response data into a Space struct.
Parses API response data into a Space struct, raising on error.
Embedded schema for Neural Space entities.
Parses API response data into a Space struct.
Parses API response data into a Space struct, raising on error.