TamaEx.Perception (TamaEx v0.1.18)
View SourceClient for interacting with Perception API endpoints.
Summary
Functions
Gets a chain by slug from a specific space.
Functions
Gets a chain by slug from a specific space.
Parameters
- client - The HTTP client
- space - The space identifier (can be space_id string or Space struct)
- slug - The slug identifier for the chain
Examples
iex> client = %Req.Request{options: %{base_url: "https://api.example.com/provision"}}
iex> {:ok, _} = TamaEx.validate_client(client, ["provision"])
iex> is_binary("space_123") and is_binary("my-chain")
true
iex> space = %TamaEx.Neural.Space{id: "space_123", name: "Test", provision_state: "active"}
iex> space.id
"space_123"
iex> attrs = %{"name" => "Test Chain", "provision_state" => "active"}
iex> chain = TamaEx.Perception.Chain.parse(attrs)
iex> chain.name
"Test Chain"